@@ -22,7 +22,7 @@
 
 using namespace std;
 
-CharTranslator::CharTranslator(TextFormatter *f)
+CharTranslator::CharTranslator(TextFormatterPtr f)
   : TextFormatter(f), counter(0), reg_exp(0)
 {
 }
@@ -34,17 +34,17 @@ CharTranslator::~CharTranslator()
 }
 
 void
-CharTranslator::set_translation(char to_translate, 
-                                const char *translate_into)
+CharTranslator::set_translation(const std::string &to_translate,
+                                const std::string &translate_into)
 {
   ostringstream exp;
   exp << (translation_exp.size() ? "|" : "") << "(" << to_translate << ")";
-  
+
   translation_exp += exp.str();
-  
+
   ostringstream format;
   format << "(?" << ++counter << translate_into << ")";
-  
+
   translation_format += format.str();
 }
 
@@ -55,14 +55,14 @@ CharTranslator::preformat(const string &text)
   if (!translation_exp.size()) {
     return text;
   }
-  
+
   if (! reg_exp)
     reg_exp = new boost::regex(translation_exp);
-  
+
   std::ostringstream preformat_text(std::ios::out | std::ios::binary);
   std::ostream_iterator<char, char> oi(preformat_text);
-  boost::regex_replace(oi, text.begin(), text.end(), *reg_exp, 
+  boost::regex_replace(oi, text.begin(), text.end(), *reg_exp,
                        translation_format, boost::match_default | boost::format_all);
-  
+
   return preformat_text.str();
 }
