@@ -37,13 +37,20 @@ class CharTranslator : public TextFormatter
    std::string translation_format; // translate into
    boost::regex *reg_exp;
 
-   virtual const std::string preformat(const std::string &text); 
-   
+   virtual const std::string preformat(const std::string &text);
+
  public:
-  CharTranslator(TextFormatter *f = 0);
+  CharTranslator(TextFormatterPtr f = TextFormatterPtr());
   virtual ~CharTranslator();
 
-  void set_translation(char, const char *);
+  void set_translation(const std::string &s1, const std::string &s2);
+
+  const std::string toString() const
+  {
+    return translation_exp + " -> " + translation_format;
+  }
 } ;
 
+typedef boost::shared_ptr<CharTranslator> CharTranslatorPtr;
+
 #endif // _CHARTRANSLATOR_H
