@@ -20,6 +20,9 @@
 /* 
  * src/envmapper.h -- prototypes and definitions for src/envmapper.c
  *
+ * 19.04.2001 [SPX] * added ENV_REQUEST_METHOD
+ *                  * added MAX_QUERY_STRING_LEN
+ *                  * added REQUEST_METHOD_GET
  * 06.04.2001 [SPX] completed initial revision
  * 05.04.2001 [SPX] initial revision
  *
@@ -29,8 +32,11 @@
 #ifndef _ENVMAPPER_H__
 #define _ENVMAPPER_H__
 
-#define ENV_QUERY_STRING    "QUERY_STRING"
-#define MAX_PARAM_AMOUNT    128
+#define ENV_REQUEST_METHOD    "REQUEST_METHOD"
+#define ENV_QUERY_STRING      "QUERY_STRING"
+#define REQUEST_METHOD_GET    "GET"
+#define MAX_PARAM_AMOUNT      128
+#define MAX_QUERY_STRING_LEN  512
 
 #ifdef __cplusplus
 extern "C" {
