@@ -29,20 +29,17 @@ class GeneratorMap
   MapType generatormap;
   TextGenerator *default_generator;
 
-  virtual TextGenerator *missingGenerator(const std::string &elem);
-
  public:
   GeneratorMap();
-  virtual ~GeneratorMap();
+  ~GeneratorMap();
 
   TextGenerator *getGenerator(const std::string &elem);
   void addGenerator(const std::string &elem, TextGenerator *gen);
 
   void setDefaultGenerator(TextGenerator *g);
 
-  void generate( const std::string &elem, const std::string &s );
-  void generateln( const std::string &elem, const std::string &s );
   void generateEntire( const std::string &elem, const std::string &s );
+  void generateNL( const std::string &s );
 };
 
 #endif
