@@ -15,12 +15,15 @@
 #include "linenumdigit.h"
 #include "my_sstream.h"
 #include "maingeneratormap.h"
-#include "textgen.h"
+#include "textgenerator.h"
+#include "textstyle.h"
 
 using namespace std;
 
-LineOutputGenerator::LineOutputGenerator(OutputBuffer& buff, ostream& os, bool genref):
-  OutputGenerator(buff, os), generate_ref(genref), line_num(1)
+LineOutputGenerator::LineOutputGenerator(OutputBuffer& buff, ostream& os,
+    TextStyle *anch, bool genref, const string &prefix):
+  OutputGenerator(buff, os), generate_ref(genref && ! anch->empty()),
+  anchor(anch), anchor_line_prefix(prefix), line_num(1)
 {
   line_num_generator = generatormap->getGenerator("linenum");
 }
@@ -50,15 +53,17 @@ LineOutputGenerator::generate_line_info()
   ostringstream sout;
 
   sout << std::setw (line_num_digit) << std::setfill ('0')
-        << line_num << ": ";
+        << line_num << ":";
 
   string line_str = line_num_generator->generateEntire(sout.str().c_str());
 
-  if (generate_ref) {// Oliver Fischer * plexus@snafu.de
+  if (generate_ref) {
+    ostringstream line_n;
+    line_n << anchor_line_prefix << line_num;
     sout.str("");
-    sout << "<a name=\"line" << line_num << "\">" << line_str << "</a>";
+    sout << anchor->output(line_str, line_n.str());
     line_str = sout.str();
   }
 
-  output_string(line_str);
+  output_string(line_str + " ");
 }
