@@ -85,3 +85,9 @@ void exitError(const std::string &error)
   cerr << PACKAGE << ": " << error << endl;
   exit(EXIT_FAILURE);
 }
+
+void foundBug(const std::string &error, const std::string &file, int line)
+{
+  cerr << PACKAGE << ": " << error << ", " << file << ":" << line << endl;
+  exit(EXIT_FAILURE);
+}
