@@ -65,15 +65,19 @@
      BOLD = 258,
      ITALICS = 259,
      UNDERLINE = 260,
-     KEY = 261,
-     COLOR = 262
+     FIXED = 261,
+     NOTFIXED = 262,
+     KEY = 263,
+     COLOR = 264
    };
 #endif
 #define BOLD 258
 #define ITALICS 259
 #define UNDERLINE 260
-#define KEY 261
-#define COLOR 262
+#define FIXED 261
+#define NOTFIXED 262
+#define KEY 263
+#define COLOR 264
 
 
 
@@ -122,6 +126,7 @@ static void yyerror( char *s ) ;
 int line = 1 ;
 
 static void add_tag(Tags *tags, Tag *t);
+static Tags *parsed_tags = 0;
 
 extern int opsc_lex() ;
 extern FILE *opsc_in ;
@@ -142,16 +147,17 @@ extern FILE *opsc_in ;
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 49 "./optparser.yy"
+#line 50 "./optparser.yy"
 typedef union YYSTYPE {
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
-  int flag ;
+  TagStyle flag ;
   Tag *tag ;
   Tags *tags ;
+  TagStyles *tagstyles;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 155 "optparser.cc"
+#line 161 "optparser.cc"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -163,7 +169,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 167 "optparser.cc"
+#line 173 "optparser.cc"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -269,20 +275,20 @@ union yyalloc
 /* YYFINAL -- State number of the termination state. */
 #define YYFINAL  6
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   9
+#define YYLAST   11
 
 /* YYNTOKENS -- Number of terminals. */
-#define YYNTOKENS  10
+#define YYNTOKENS  12
 /* YYNNTS -- Number of nonterminals. */
-#define YYNNTS  7
+#define YYNNTS  8
 /* YYNRULES -- Number of rules. */
-#define YYNRULES  12
+#define YYNRULES  15
 /* YYNRULES -- Number of states. */
-#define YYNSTATES  17
+#define YYNSTATES  20
 
 /* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
 #define YYUNDEFTOK  2
-#define YYMAXUTOK   262
+#define YYMAXUTOK   264
 
 #define YYTRANSLATE(YYX) 						\
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
@@ -294,8 +300,8 @@ static const unsigned char yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-       2,     2,     2,     2,     9,     2,     2,     2,     2,     2,
-       2,     2,     2,     2,     2,     2,     2,     2,     2,     8,
+       2,     2,     2,     2,    11,     2,     2,     2,     2,     2,
+       2,     2,     2,     2,     2,     2,     2,     2,     2,    10,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -316,7 +322,7 @@ static const unsigned char yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
-       5,     6,     7
+       5,     6,     7,     8,     9
 };
 
 #if YYDEBUG
@@ -324,23 +330,24 @@ static const unsigned char yytranslate[] =
    YYRHS.  */
 static const unsigned char yyprhs[] =
 {
-       0,     0,     3,     5,     8,    10,    11,    17,    21,    23,
-      24,    26,    28
+       0,     0,     3,     5,     8,    10,    11,    17,    18,    20,
+      24,    26,    28,    30,    32,    34
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS. */
 static const yysigned_char yyrhs[] =
 {
-      11,     0,    -1,    12,    -1,    12,    13,    -1,    13,    -1,
-      -1,     6,     7,    14,    15,     8,    -1,    15,     9,    16,
-      -1,    16,    -1,    -1,     3,    -1,     4,    -1,     5,    -1
+      13,     0,    -1,    14,    -1,    14,    15,    -1,    15,    -1,
+      -1,     8,     9,    16,    17,    10,    -1,    -1,    18,    -1,
+      18,    11,    19,    -1,    19,    -1,     3,    -1,     4,    -1,
+       5,    -1,     6,    -1,     7,    -1
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    66,    66,    69,    70,    74,    73,    87,    88,    91,
-      92,    93,    94
+       0,    69,    69,    72,    73,    77,    76,    90,    91,    94,
+      95,    98,    99,   100,   101,   102
 };
 #endif
 
@@ -349,9 +356,9 @@ static const unsigned char yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "BOLD", "ITALICS", "UNDERLINE", "KEY",
-  "COLOR", "';'", "','", "$accept", "globaltags", "options", "option",
-  "@1", "values", "value", 0
+  "$end", "error", "$undefined", "BOLD", "ITALICS", "UNDERLINE", "FIXED",
+  "NOTFIXED", "KEY", "COLOR", "';'", "','", "$accept", "globaltags",
+  "options", "option", "@1", "stylevalues", "values", "value", 0
 };
 #endif
 
@@ -360,22 +367,23 @@ static const char *const yytname[] =
    token YYLEX-NUM.  */
 static const unsigned short int yytoknum[] =
 {
-       0,   256,   257,   258,   259,   260,   261,   262,    59,    44
+       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
+      59,    44
 };
 # endif
 
 /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
 static const unsigned char yyr1[] =
 {
-       0,    10,    11,    12,    12,    14,    13,    15,    15,    16,
-      16,    16,    16
+       0,    12,    13,    14,    14,    16,    15,    17,    17,    18,
+      18,    19,    19,    19,    19,    19
 };
 
 /* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
 static const unsigned char yyr2[] =
 {
-       0,     2,     1,     2,     1,     0,     5,     3,     1,     0,
-       1,     1,     1
+       0,     2,     1,     2,     1,     0,     5,     0,     1,     3,
+       1,     1,     1,     1,     1,     1
 };
 
 /* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
@@ -383,29 +391,29 @@ static const unsigned char yyr2[] =
    means the default is an error.  */
 static const unsigned char yydefact[] =
 {
-       0,     0,     0,     2,     4,     5,     1,     3,     9,    10,
-      11,    12,     0,     8,     6,     9,     7
+       0,     0,     0,     2,     4,     5,     1,     3,     7,    11,
+      12,    13,    14,    15,     0,     8,    10,     6,     0,     9
 };
 
 /* YYDEFGOTO[NTERM-NUM]. */
 static const yysigned_char yydefgoto[] =
 {
-      -1,     2,     3,     4,     8,    12,    13
+      -1,     2,     3,     4,     8,    14,    15,    16
 };
 
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
-#define YYPACT_NINF -7
+#define YYPACT_NINF -9
 static const yysigned_char yypact[] =
 {
-      -1,     0,     6,    -1,    -7,    -7,    -7,    -7,    -3,    -7,
-      -7,    -7,    -5,    -7,    -7,    -3,    -7
+      -2,    -4,     7,    -2,    -9,    -9,    -9,    -9,    -3,    -9,
+      -9,    -9,    -9,    -9,    -1,     0,    -9,    -9,    -3,    -9
 };
 
 /* YYPGOTO[NTERM-NUM].  */
 static const yysigned_char yypgoto[] =
 {
-      -7,    -7,    -7,     5,    -7,    -7,    -6
+      -9,    -9,    -9,     5,    -9,    -9,    -9,    -8
 };
 
 /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
@@ -415,20 +423,22 @@ static const yysigned_char yypgoto[] =
 #define YYTABLE_NINF -1
 static const unsigned char yytable[] =
 {
-       9,    10,    11,    14,    15,     1,     6,     5,     7,    16
+       9,    10,    11,    12,    13,     5,     1,     6,     7,    17,
+      19,    18
 };
 
 static const unsigned char yycheck[] =
 {
-       3,     4,     5,     8,     9,     6,     0,     7,     3,    15
+       3,     4,     5,     6,     7,     9,     8,     0,     3,    10,
+      18,    11
 };
 
 /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
    symbol of state STATE-NUM.  */
 static const unsigned char yystos[] =
 {
-       0,     6,    11,    12,    13,     7,     0,    13,    14,     3,
-       4,     5,    15,    16,     8,     9,    16
+       0,     8,    13,    14,    15,     9,     0,    15,    16,     3,
+       4,     5,     6,     7,    17,    18,    19,    10,    11,    19
 };
 
 #if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
@@ -1040,22 +1050,22 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 66 "./optparser.yy"
-    { setTags( yyvsp[0].tags ) ; }
+#line 69 "./optparser.yy"
+    { parsed_tags = yyvsp[0].tags; }
     break;
 
   case 3:
-#line 69 "./optparser.yy"
+#line 72 "./optparser.yy"
     { add_tag( yyvsp[-1].tags, yyvsp[0].tag ) ; }
     break;
 
   case 4:
-#line 70 "./optparser.yy"
+#line 73 "./optparser.yy"
     { yyval.tags = new Tags() ; yyval.tags->AddTag( yyvsp[0].tag ) ;  }
     break;
 
   case 5:
-#line 74 "./optparser.yy"
+#line 77 "./optparser.yy"
     {
                  printMessage( *yyvsp[-1].string ) ;
                  printMessage( *yyvsp[0].string ) ;
@@ -1063,45 +1073,60 @@ yyreduce:
     break;
 
   case 6:
-#line 79 "./optparser.yy"
+#line 82 "./optparser.yy"
     {
-	       yyval.tag = new Tag( *yyvsp[-4].string, *yyvsp[-3].string ) ;
-               yyval.tag->SetFlags(yyvsp[-1].flag) ;
+               yyval.tag = new Tag( *yyvsp[-4].string, *yyvsp[-3].string ) ;
+               yyval.tag->setStyles(TagStylesPtr(yyvsp[-1].tagstyles)) ;
                delete yyvsp[-4].string;
                delete yyvsp[-3].string;
-	     }
+             }
     break;
 
   case 7:
-#line 87 "./optparser.yy"
-    { yyval.flag = yyvsp[-2].flag | yyvsp[0].flag ; }
+#line 90 "./optparser.yy"
+    { yyval.tagstyles = 0 ; printMessage( " (no options) " ) ; }
     break;
 
   case 9:
-#line 91 "./optparser.yy"
-    { yyval.flag = 0 ; printMessage( " (no options) " ) ; }
+#line 94 "./optparser.yy"
+    { yyval.tagstyles = yyvsp[-2].tagstyles; yyval.tagstyles->push_back(yyvsp[0].flag) ; }
     break;
 
   case 10:
-#line 92 "./optparser.yy"
-    { printMessage( " - bold" ) ; yyval.flag = ISBOLD ; }
+#line 95 "./optparser.yy"
+    { yyval.tagstyles = new TagStyles; yyval.tagstyles->push_back(yyvsp[0].flag); }
     break;
 
   case 11:
-#line 93 "./optparser.yy"
-    { printMessage( " - italics" ) ; yyval.flag = ISITALIC ; }
+#line 98 "./optparser.yy"
+    { printMessage( " - bold" ) ; yyval.flag = ISBOLD ; }
     break;
 
   case 12:
-#line 94 "./optparser.yy"
+#line 99 "./optparser.yy"
+    { printMessage( " - italics" ) ; yyval.flag = ISITALIC ; }
+    break;
+
+  case 13:
+#line 100 "./optparser.yy"
     { printMessage( " - underline" ) ; yyval.flag = ISUNDERLINE ; }
     break;
 
+  case 14:
+#line 101 "./optparser.yy"
+    { printMessage( " - fixed" ) ; yyval.flag = ISFIXED ; }
+    break;
+
+  case 15:
+#line 102 "./optparser.yy"
+    { printMessage( " - notfixed" ) ; yyval.flag = ISNOTFIXED ; }
+    break;
+
 
     }
 
 /* Line 1010 of yacc.c.  */
-#line 1105 "optparser.cc"
+#line 1130 "optparser.cc"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1326,23 +1351,27 @@ yyreturn:
 }
 
 
-#line 97 "./optparser.yy"
+#line 105 "./optparser.yy"
 
 
-char *current_file = 0;
+string current_file;
 
-void
+Tags *
 parseTags(const string &path, const string &name)
 {
   // opens the file for yylex
   opsc_in = open_data_file_stream(path, name);
 
+  current_file = (path.size() ? path + "/" : "") + name;
+
   printMessage_noln( "Parsing ", cerr ) ;
-  printMessage_noln (name, cerr);
+  printMessage_noln (current_file, cerr);
   printMessage( " file ...", cerr ) ;
+  parsed_tags = 0;
   yyparse() ;
   printMessage( "Parsing done!", cerr ) ;
   fclose(opsc_in);
+  return parsed_tags;
 }
 
 void
