@@ -34,8 +34,7 @@ void add_exp(RegExpStatePtr state, const string &orig, const string &exp, Parser
   try {
     state->add_exp(exp, parserInfo, f);
   } catch (boost::bad_expression &e) {
-    printError("wrong original expression: " + orig);
-    throw e;
+    exitError("wrong original expression: " + orig);
   }
 }
 
@@ -92,12 +91,12 @@ RegExpStateBuilder::build(LangElems *elems, RegExpStatePointer state)
       try {
         temp_state->freeze();
       } catch (boost::bad_expression &e) {
-        printError("problem in this expression: " + (*it)->toString());
-        throw e;
+        exitError("problem in this expression: " + (*it)->toString());
       }
     }
-  } else
-    throw boost::bad_expression("internal error");
+  } else {
+    foundBug("bug in expression parsing", __FILE__, __LINE__);
+  }
 }
 
 void
