@@ -17,13 +17,13 @@ class Untabifier : public TextFormatter
 {
  public:
 
-  Untabifier (int nSpacesPerTab, TextFormatter *f = 0) : 
+  Untabifier (int nSpacesPerTab, TextFormatterPtr f = TextFormatterPtr()) :
     TextFormatter(f), nSpacesPerTab_ (nSpacesPerTab), n_ (0)
     {
     }
 
   virtual const string preformat( const std::string &text );
-  
+
  private:
 
   const int nSpacesPerTab_;
