@@ -14,12 +14,16 @@
 
 #include <boost/regex.hpp>
 #include <boost/shared_ptr.hpp>
+#include <boost/weak_ptr.hpp>
 #include <deque>
+#include <vector>
 #include "my_sstream.h"
+#include "parserinfo.h"
 
 struct RegExpState;
 
 typedef boost::shared_ptr<RegExpState> RegExpStatePtr;
+typedef boost::weak_ptr<RegExpState> RegExpStatePtrW;
 
 struct RegExpFormatter
 {
@@ -33,11 +37,20 @@ struct RegExpFormatter
   RegExpStatePtr getNextState() const;
 
   private:
-    RegExpStatePtr next_state;
+    RegExpStatePtrW next_state;
+    RegExpStatePtr next_state_strong;
+    /*
+      FIXME
+      the next_state is a weak pointer when there's a "nested" situation.
+      This allows to avoid cycles, that otherwise would prevent memory from
+      being correctly freed.
+    */
 };
 
 typedef boost::shared_ptr<RegExpFormatter> RegExpFormatterPtr;
 typedef std::deque<RegExpFormatterPtr> format_vector;
+typedef std::pair<std::string, ParserInfo> SubExpressionInfo;
+typedef std::vector<SubExpressionInfo> SubExpressions;
 
 /**
 class representing a state for the regular expression engine
@@ -47,6 +60,7 @@ class representing a state for the regular expression engine
 struct RegExpState
 {
   boost::regex reg_exp;
+  SubExpressions subExpressions;
   format_vector formatters;
   int current_formatter;
   std::ostringstream buffer;
@@ -54,7 +68,7 @@ struct RegExpState
   RegExpState() : formatters(1), current_formatter(0) {}
 
   const std::string &get_elem(int index = -1);
-  void add_exp(const std::string &s, RegExpFormatterPtr f);
+  void add_exp(const std::string &s, ParserInfo *parserInfo, RegExpFormatterPtr f);
   void freeze() throw(boost::bad_expression);
   void add_normal_formatter(RegExpFormatterPtr f);
   RegExpFormatterPtr getLastFormatter() const { return formatters[formatters.size()-1];}
